@@ -1,3 +1,5 @@
+from django.utils import timezone
+
 from pymess.backend.push import PushNotificationBackend
 from pymess.models import PushNotificationMessage
 
@@ -6,4 +8,4 @@ class DummyPushNotificationBackend(PushNotificationBackend):
     """Dummy push notification backend used for testing environments. Backend only logs messages to the database."""
 
     def publish_message(self, message):
-        self._update_message_after_sending(message, state=PushNotificationMessage.STATE.DEBUG)
+        self._update_message_after_sending(message, state=PushNotificationMessage.STATE.DEBUG, sent_at=timezone.now())
